summaryrefslogtreecommitdiffstats
path: root/src/memberdef.cpp
diff options
context:
space:
mode:
authorDimitri van Heesch <doxygen@gmail.com>2019-01-08 18:55:03 (GMT)
committerDimitri van Heesch <doxygen@gmail.com>2019-01-08 18:55:03 (GMT)
commitfec80946ad8a21d81aab23896a816122ade245d3 (patch)
tree2662feb93bc2e6f98089ae151020093fbbeb5431 /src/memberdef.cpp
parent08c27fdc4cffa3a30d3d2e2b9ea447146aad25ce (diff)
downloadDoxygen-fec80946ad8a21d81aab23896a816122ade245d3.zip
Doxygen-fec80946ad8a21d81aab23896a816122ade245d3.tar.gz
Doxygen-fec80946ad8a21d81aab23896a816122ade245d3.tar.bz2
Shortened EXTRACT_PRIVATE_VIRTUAL to EXTRACT_PRIV_VIRTUAL to deal with max length limitation
Diffstat (limited to 'src/memberdef.cpp')
-rw-r--r--src/memberdef.cpp16
1 files changed, 9 insertions, 7 deletions
diff --git a/src/memberdef.cpp b/src/memberdef.cpp
index 58a2b12..bcef5ac 100644
--- a/src/memberdef.cpp
+++ b/src/memberdef.cpp
@@ -1080,7 +1080,7 @@ QCString MemberDef::anchor() const
void MemberDef::_computeLinkableInProject()
{
static bool extractStatic = Config_getBool(EXTRACT_STATIC);
- static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIVATE_VIRTUAL);
+ static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIV_VIRTUAL);
m_isLinkableCached = 2; // linkable
//printf("MemberDef::isLinkableInProject(name=%s)\n",name().data());
if (isHidden())
@@ -1134,7 +1134,8 @@ void MemberDef::_computeLinkableInProject()
m_isLinkableCached = 1; // in file (and not in namespace) but file not linkable
return;
}
- if ((!protectionLevelVisible(m_impl->prot) && m_impl->mtype!=MemberType_Friend) && !(m_impl->prot==Private && m_impl->virt!=Normal && extractPrivateVirtual))
+ if ((!protectionLevelVisible(m_impl->prot) && m_impl->mtype!=MemberType_Friend) &&
+ !(m_impl->prot==Private && m_impl->virt!=Normal && extractPrivateVirtual))
{
//printf("private and invisible!\n");
m_isLinkableCached = 1; // hidden due to protection
@@ -1316,7 +1317,7 @@ ClassDef *MemberDef::getClassDefOfAnonymousType()
bool MemberDef::isBriefSectionVisible() const
{
static bool extractStatic = Config_getBool(EXTRACT_STATIC);
- static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIVATE_VIRTUAL);
+ static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIV_VIRTUAL);
static bool hideUndocMembers = Config_getBool(HIDE_UNDOC_MEMBERS);
static bool briefMemberDesc = Config_getBool(BRIEF_MEMBER_DESC);
static bool repeatBrief = Config_getBool(REPEAT_BRIEF);
@@ -1368,7 +1369,7 @@ bool MemberDef::isBriefSectionVisible() const
// only include members that are non-private unless EXTRACT_PRIVATE is
// set to YES or the member is part of a group. And as a special case,
// private *documented* virtual members are shown if EXTRACT_PRIVATE_VIRTUAL
// is set to YES
bool visibleIfPrivate = (protectionLevelVisible(protection()) ||
m_impl->mtype==MemberType_Friend ||
@@ -1644,7 +1645,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
if (!name().isEmpty() && name().at(0)!='@') // hide anonymous stuff
{
static bool extractPrivate = Config_getBool(EXTRACT_PRIVATE);
- static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIVATE_VIRTUAL);
+ static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIV_VIRTUAL);
static bool extractStatic = Config_getBool(EXTRACT_STATIC);
//printf("Member name=`%s gd=%p md->groupDef=%p inGroup=%d isLinkable()=%d hasDocumentation=%d\n",name().data(),gd,getGroupDef(),inGroup,isLinkable(),hasDocumentation());
if (!(name().isEmpty() || name().at(0)=='@') && // name valid
@@ -1902,7 +1903,7 @@ bool MemberDef::isDetailedSectionLinkable() const
static bool briefMemberDesc = Config_getBool(BRIEF_MEMBER_DESC);
static bool hideUndocMembers = Config_getBool(HIDE_UNDOC_MEMBERS);
static bool extractStatic = Config_getBool(EXTRACT_STATIC);
- static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIVATE_VIRTUAL);
+ static bool extractPrivateVirtual = Config_getBool(EXTRACT_PRIV_VIRTUAL);
// the member has details documentation for any of the following reasons
bool docFilter =
@@ -1940,7 +1941,8 @@ bool MemberDef::isDetailedSectionLinkable() const
// only include members that are non-private unless EXTRACT_PRIVATE is
// set to YES or the member is part of a group
- bool privateFilter = protectionLevelVisible(protection()) || m_impl->mtype==MemberType_Friend || (m_impl->prot==Private && m_impl->virt!=Normal && extractPrivateVirtual);
+ bool privateFilter = protectionLevelVisible(protection()) || m_impl->mtype==MemberType_Friend ||
+ (m_impl->prot==Private && m_impl->virt!=Normal && extractPrivateVirtual);
// member is part of an anonymous scope that is the type of
// another member in the list.
@@ -1368,7 +1369,7 @@ bool MemberDef::isBriefSectionVisible() const
// only include members that are non-private unless EXTRACT_PRIVATE is
// set to YES or the member is part of a group. And as a special case,
- // private *documented* virtual members are shown if EXTRACT_PRIVATE_VIRTUAL
+ // private *documented* virtual members are shown if EXTRACT_PRIV_VIRTUAL
// is set to YES
bool visibleIfPrivate = (protectionLevelVisible(protection()) ||